require 'rainbow'
require 'm_and_m'
require 'm_and_m/server'
require 'm_and_m/preferences'

class MAndM::Cli
  attr_reader :preferences

  def initialize
    @preferences = MAndM::Preferences.new '.m_and_m'
  end

  def execute *args
    command = args.shift
    command = :list unless command
    send command, *args
  end

  def list
    server.messages.each do |message|
      puts "#{c :yellow, time(message["at"])} #{c :magenta, message["from"]} said #{c :green, message["message"]}"
    end
  end

  def say who, message_id
    server.say uuid_for(who), message_id
  end

private

  def server
    MAndM::Server.new url, preferences
  end

  def time at
    Time.at(at).strftime("%d/%b %H:%M:%S")
  end

  def c colour, text
    text.to_s.foreground colour
  end

  def uuid_for name
    preferences.ask "#{name}_uuid".to_sym, "What is the uuid for #{name}"
  end

  def url
    preferences.ask :url, 'What is the server url'
  end
end